## 0.1.4
0ec841c Added intermediate release type
5abbb1f Release [patch] version to 0.1.3

## 0.1.2
6250aec Write intermediate content to release/ directory
9aab64c Only push if allowed
babc683 Fix release diff naming
912cfc0 Adding version bump utils
e8ad6b6 Adding version bump utils
c26620a Fix url in readme
dac5257 Moved helper scripts to scripts directory

